/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasGradient.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomCanvasGradient.h"
#include "gdom/GdomDOMObject.h"
#include "gdom/PrivateGdomCanvasGradient.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateIntGdomCanvasGradient.h"
#include "glib-object.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
gpointer toGDOM(WebCore::CanvasGradient* obj)
{
    return WebCore::cacheDOMObject<WebCore::CanvasGradient, GDOMCanvasGradient>(obj);
}
} /* namespace WebCore */
extern "C" {

GDOMCanvasGradient::GDOMCanvasGradient(PassRefPtr<WebCore::CanvasGradient> impl)
    : GDOMObject()
    , m_impl(impl)
{
}

GDOMCanvasGradient::~GDOMCanvasGradient()
{
    m_impl.get()->deref();
    WebCore::GDOMScriptInterpreter::forgetDOMObject(m_impl.get());

}

void
gdom_canvas_gradient_add_color_stop (GdomCanvasGradient *thiz, gfloat offset, gchar * color)
{
    g_return_if_fail (thiz);
    WebCore::CanvasGradient * item = (gdom_canvas_gradient_get_private(thiz));
    g_return_if_fail (item);
    g_return_if_fail (color);
    WebCore::String _g_color = WebCore::String::fromUTF8(color);
    item->addColorStop(offset, _g_color);

}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "CanvasGradient.h"
#include <gdom/GdomCanvasGradient.h>
#include <gdom/PrivateGdomCanvasGradient.h>
#include <gdom/PrivateIntGdomCanvasGradient.h>
#include <gdom/GdomCanvasGradientprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomCanvasGradient, gdom_canvas_gradient, GDOM_TYPE_DOM_OBJECT);

/*
struct _GdomCanvasGradientPrivate {
    class WebCore::CanvasGradient *item;
};

#define GDOM_CANVAS_GRADIENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_CANVAS_GRADIENT, GdomCanvasGradientPrivate))
*/
G_END_DECLS
WebCore::CanvasGradient *
gdom_canvas_gradient_get_private(GdomCanvasGradient *request)
{
    GDOMCanvasGradient *res;
    res = static_cast<GDOMCanvasGradient*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::CanvasGradient*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
};


static void gdom_canvas_gradient_finalize(GObject* object)
{
    /*GdomCanvasGradient* request = GDOM_CANVAS_GRADIENT(object);*/
    /*GdomCanvasGradientPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_DOM_OBJECT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_canvas_gradient_parent_class)->finalize(object);
}

static void gdom_canvas_gradient__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomCanvasGradient *self = GDOM_CANVAS_GRADIENT(object);
    WebCore::CanvasGradient * gself = (gdom_canvas_gradient_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_canvas_gradient__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomCanvasGradient *self = GDOM_CANVAS_GRADIENT(object);
    WebCore::CanvasGradient * gself = (gdom_canvas_gradient_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_canvas_gradient_class_init(GdomCanvasGradientClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_canvas_gradient_finalize;
    g_klass->set_property = gdom_canvas_gradient__set_property_fn;
    g_klass->get_property = gdom_canvas_gradient__get_property_fn;





    /*g_type_class_remove_private(requestClass, sizeof(GdomCanvasGradientPrivate));*/
}

static void gdom_canvas_gradient_init(GdomCanvasGradient* request)
{
    /*GdomCanvasGradientPrivate* priv = GDOM_CANVAS_GRADIENT_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

